# fish completion for imunify360-agent
# Auto-generated by imunify360-agent completions fish

complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a '3rdparty'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'add-sudouser'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'advisor'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'analyst-cleanup'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'auth-cloud'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'auth-cloud-refresh-token'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'billing'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'check-domains'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'checkdb'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'completions'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'config'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'delete-sudouser'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'disable-plugin'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'doctor'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'enable-plugin'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'eula'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'feature-management'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'get-news'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'get-package-versions'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'hook'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'infected-domains'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'list-docroots'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'login'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'notifications-config'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'permissions'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'plesk-stats'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'register'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'rstatus'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'support'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'unregister'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'update'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'update-license'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'version'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'wakeup'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -f -a 'wordpress-plugin'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -l 'console-log-level'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -l 'log-config'
complete -c imunify360-agent -n 'not __fish_seen_subcommand_from 3rdparty add-sudouser advisor analyst-cleanup auth-cloud auth-cloud-refresh-token billing check-domains checkdb completions config delete-sudouser disable-plugin doctor enable-plugin eula feature-management get-news get-package-versions hook infected-domains list-docroots login notifications-config permissions plesk-stats register rstatus support unregister update update-license version wakeup wordpress-plugin' -l 'remote-addr'
complete -c imunify360-agent -n '__fish_seen_subcommand_from 3rdparty && not __fish_seen_subcommand_from conflicts' -f -a 'conflicts'
complete -c imunify360-agent -n '__fish_seen_subcommand_from add-sudouser' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from add-sudouser' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from add-sudouser' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from add-sudouser' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && not __fish_seen_subcommand_from apply apply-all' -f -a 'apply'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && not __fish_seen_subcommand_from apply apply-all' -f -a 'apply-all'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && not __fish_seen_subcommand_from get-requests is-allowed request' -f -a 'get-requests'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && not __fish_seen_subcommand_from get-requests is-allowed request' -f -a 'is-allowed'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && not __fish_seen_subcommand_from get-requests is-allowed request' -f -a 'request'
complete -c imunify360-agent -n '__fish_seen_subcommand_from auth-cloud' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from auth-cloud' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from auth-cloud' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from auth-cloud-refresh-token' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from auth-cloud-refresh-token' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from auth-cloud-refresh-token' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && not __fish_seen_subcommand_from get-config sync' -f -a 'get-config'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && not __fish_seen_subcommand_from get-config sync' -f -a 'sync'
complete -c imunify360-agent -n '__fish_seen_subcommand_from check-domains' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from check-domains' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from check-domains' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from checkdb' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from checkdb' -l 'no-recreate-schema'
complete -c imunify360-agent -n '__fish_seen_subcommand_from checkdb' -l 'recreate-schema'
complete -c imunify360-agent -n '__fish_seen_subcommand_from checkdb' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from checkdb' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && not __fish_seen_subcommand_from get-many patch patch-many show update' -f -a 'get-many'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && not __fish_seen_subcommand_from get-many patch patch-many show update' -f -a 'patch'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && not __fish_seen_subcommand_from get-many patch patch-many show update' -f -a 'patch-many'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && not __fish_seen_subcommand_from get-many patch patch-many show update' -f -a 'show'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && not __fish_seen_subcommand_from get-many patch patch-many show update' -f -a 'update'
complete -c imunify360-agent -n '__fish_seen_subcommand_from delete-sudouser' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from delete-sudouser' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from delete-sudouser' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from delete-sudouser' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from disable-plugin' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from disable-plugin' -l 'plugin-name'
complete -c imunify360-agent -n '__fish_seen_subcommand_from disable-plugin' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from disable-plugin' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from doctor' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from doctor' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from doctor' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from enable-plugin' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from enable-plugin' -l 'plugin-name'
complete -c imunify360-agent -n '__fish_seen_subcommand_from enable-plugin' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from enable-plugin' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && not __fish_seen_subcommand_from accept show' -f -a 'accept'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && not __fish_seen_subcommand_from accept show' -f -a 'show'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'defaults'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'disable'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'enable'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'get'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'list'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'native'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && not __fish_seen_subcommand_from defaults disable enable get list native show' -f -a 'show'
complete -c imunify360-agent -n '__fish_seen_subcommand_from get-news' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from get-news' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from get-news' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from get-package-versions' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from get-package-versions' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from get-package-versions' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && not __fish_seen_subcommand_from add add-native delete list' -f -a 'add'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && not __fish_seen_subcommand_from add add-native delete list' -f -a 'add-native'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && not __fish_seen_subcommand_from add add-native delete list' -f -a 'delete'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && not __fish_seen_subcommand_from add add-native delete list' -f -a 'list'
complete -c imunify360-agent -n '__fish_seen_subcommand_from infected-domains' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from infected-domains' -l 'limit'
complete -c imunify360-agent -n '__fish_seen_subcommand_from infected-domains' -l 'offset'
complete -c imunify360-agent -n '__fish_seen_subcommand_from infected-domains' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from infected-domains' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from list-docroots' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from list-docroots' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from list-docroots' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && not __fish_seen_subcommand_from get pam' -f -a 'get'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && not __fish_seen_subcommand_from get pam' -f -a 'pam'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && not __fish_seen_subcommand_from patch show update' -f -a 'patch'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && not __fish_seen_subcommand_from patch show update' -f -a 'show'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && not __fish_seen_subcommand_from patch show update' -f -a 'update'
complete -c imunify360-agent -n '__fish_seen_subcommand_from permissions && not __fish_seen_subcommand_from list' -f -a 'list'
complete -c imunify360-agent -n '__fish_seen_subcommand_from plesk-stats' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from plesk-stats' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from plesk-stats' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from register' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from register' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from register' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from rstatus' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from rstatus' -l 'no-paid'
complete -c imunify360-agent -n '__fish_seen_subcommand_from rstatus' -l 'paid'
complete -c imunify360-agent -n '__fish_seen_subcommand_from rstatus' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from rstatus' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && not __fish_seen_subcommand_from send' -f -a 'send'
complete -c imunify360-agent -n '__fish_seen_subcommand_from unregister' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from unregister' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from unregister' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'force'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'list'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'no-force'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'no-list'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -l 'version'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update-license' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update-license' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from update-license' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from version' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from version' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from version' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wakeup' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wakeup' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wakeup' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'install-and-update'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'install-on-new-sites'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'list-incidents'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'list-sites'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'rules'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'tidy-up'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'update'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && not __fish_seen_subcommand_from install-and-update install-on-new-sites list-incidents list-sites rules tidy-up update waf' -f -a 'waf'
complete -c imunify360-agent -n '__fish_seen_subcommand_from 3rdparty && __fish_seen_subcommand_from conflicts' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from 3rdparty && __fish_seen_subcommand_from conflicts' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from 3rdparty && __fish_seen_subcommand_from conflicts' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && __fish_seen_subcommand_from apply' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && __fish_seen_subcommand_from apply' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && __fish_seen_subcommand_from apply' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && __fish_seen_subcommand_from apply-all' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && __fish_seen_subcommand_from apply-all' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from advisor && __fish_seen_subcommand_from apply-all' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from get-requests' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from get-requests' -l 'limit'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from get-requests' -l 'offset'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from get-requests' -l 'username'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from get-requests' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from get-requests' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from is-allowed' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from is-allowed' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from is-allowed' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from request' -l 'email'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from request' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from request' -l 'message'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from request' -l 'username'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from request' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from analyst-cleanup && __fish_seen_subcommand_from request' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && __fish_seen_subcommand_from get-config' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && __fish_seen_subcommand_from get-config' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && __fish_seen_subcommand_from get-config' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && __fish_seen_subcommand_from sync' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && __fish_seen_subcommand_from sync' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from billing && __fish_seen_subcommand_from sync' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from get-many' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from get-many' -l 'users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from get-many' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from get-many' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch' -l 'data'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch-many' -l 'data'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch-many' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch-many' -l 'users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch-many' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from patch-many' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && not __fish_seen_subcommand_from defaults' -f -a 'defaults'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && not __fish_seen_subcommand_from defaults' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && not __fish_seen_subcommand_from defaults' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && not __fish_seen_subcommand_from defaults' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && not __fish_seen_subcommand_from defaults' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from update' -l 'items'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from update' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from update' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from update' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from update' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && __fish_seen_subcommand_from accept' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && __fish_seen_subcommand_from accept' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && __fish_seen_subcommand_from accept' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && __fish_seen_subcommand_from show' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && __fish_seen_subcommand_from show' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from eula && __fish_seen_subcommand_from show' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from defaults' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from defaults' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from defaults' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from disable' -l 'feature'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from disable' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from disable' -l 'users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from disable' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from disable' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from enable' -l 'feature'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from enable' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from enable' -l 'users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from enable' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from enable' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from get' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from get' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from get' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from get' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from list' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from list' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from list' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && not __fish_seen_subcommand_from disable enable status' -f -a 'disable'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && not __fish_seen_subcommand_from disable enable status' -f -a 'enable'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && not __fish_seen_subcommand_from disable enable status' -f -a 'status'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -l 'limit'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -l 'offset'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -l 'order-by'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -l 'search'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from show' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add' -l 'event'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add' -l 'path'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add-native' -l 'event'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add-native' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add-native' -l 'path'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add-native' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from add-native' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from delete' -l 'event'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from delete' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from delete' -l 'path'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from delete' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from delete' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from list' -l 'event'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from list' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from list' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from hook && __fish_seen_subcommand_from list' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from get' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from get' -l 'username'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from get' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from get' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from pam' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from pam' -l 'password'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from pam' -l 'username'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from pam' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from login && __fish_seen_subcommand_from pam' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from patch' -l 'data'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from patch' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from patch' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from patch' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from show' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from show' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from show' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from update' -l 'items'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from update' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from update' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from notifications-config && __fish_seen_subcommand_from update' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from permissions && __fish_seen_subcommand_from list' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from permissions && __fish_seen_subcommand_from list' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from permissions && __fish_seen_subcommand_from list' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from permissions && __fish_seen_subcommand_from list' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'attachments'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'cln'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'description'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'email'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'subject'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from support && __fish_seen_subcommand_from send' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from install-and-update' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from install-and-update' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from install-and-update' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from install-on-new-sites' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from install-on-new-sites' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from install-on-new-sites' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'by-abuser-ip'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'by-country-code'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'by-domain'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'include-hidden'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'limit'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'no-include-hidden'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'offset'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'order-by'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'search'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'since'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'site-search'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'to'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-incidents' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-sites' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-sites' -l 'limit'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-sites' -l 'offset'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-sites' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-sites' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from list-sites' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && not __fish_seen_subcommand_from disable enable list-disabled' -f -a 'disable'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && not __fish_seen_subcommand_from disable enable list-disabled' -f -a 'enable'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && not __fish_seen_subcommand_from disable enable list-disabled' -f -a 'list-disabled'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from tidy-up' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from tidy-up' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from tidy-up' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from update' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from update' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from update' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && not __fish_seen_subcommand_from set' -f -a 'set'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && __fish_seen_subcommand_from defaults' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && __fish_seen_subcommand_from defaults' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from config && __fish_seen_subcommand_from show && __fish_seen_subcommand_from defaults' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from disable' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from disable' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from disable' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from enable' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from enable' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from enable' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from status' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from status' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from feature-management && __fish_seen_subcommand_from native && __fish_seen_subcommand_from status' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from disable' -l 'domains'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from disable' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from disable' -l 'rule'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from disable' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from disable' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from disable' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from enable' -l 'domains'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from enable' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from enable' -l 'rule'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from enable' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from enable' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from enable' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -l 'domains'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -l 'limit'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -l 'offset'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -l 'user'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from rules && __fish_seen_subcommand_from list-disabled' -s 'v'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -l 'all-users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -l 'json'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -l 'no-all-users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -l 'status'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -l 'users'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -l 'verbose'
complete -c imunify360-agent -n '__fish_seen_subcommand_from wordpress-plugin && __fish_seen_subcommand_from waf && __fish_seen_subcommand_from set' -s 'v'
